@@ -6,6 +6,10 @@
  * @package PhpMyAdmin
  */
 
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
+
 /**
  * Load vendor configuration.
  */
@@ -98,7 +102,7 @@ class PMA_Config
      */
     function checkSystem()
     {
-        $this->set('PMA_VERSION', '3.5.8');
+        $this->set('PMA_VERSION', '3.5.8.2');
         /**
          * @deprecated
          */
