@@ -3,9 +3,13 @@
 /**
  * holds the PMA_List_Database class
  *
- * @version $Id: List_Database.class.php 12218 2009-02-01 12:52:18Z lem9 $
+ * @package PhpMyAdmin
  */
 
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
+
 /**
  * the list base class
  */
@@ -23,6 +27,7 @@ require_once './libraries/List.class.php';
  * @todo ? support --skip-showdatabases and user has only global rights
  * @access public
  * @since phpMyAdmin 2.9.10
+ * @package PhpMyAdmin
  */
 /*public*/ class PMA_List_Database extends PMA_List
 {
@@ -46,7 +51,7 @@ require_once './libraries/List.class.php';
      * @access protected
      */
     protected $_show_databases_disabled = false;
-    
+
     /**
      * @var string command to retrieve databases from server
      */
@@ -55,12 +60,8 @@ require_once './libraries/List.class.php';
     /**
      * Constructor
      *
-     * @uses    PMA_List_Database::$_db_link
-     * @uses    PMA_List_Database::$_db_link_user
-     * @uses    PMA_List_Database::$_db_link_control
-     * @uses    PMA_List_Database::build()
-     * @param   mixed   $db_link_user       user database link resource|object
-     * @param   mixed   $db_link_control    control database link resource|object
+     * @param mixed   $db_link_user       user database link resource|object
+     * @param mixed   $db_link_control    control database link resource|object
      */
     public function __construct($db_link_user = null, $db_link_control = null)
     {
@@ -74,11 +75,6 @@ require_once './libraries/List.class.php';
 
     /**
      * checks if the configuration wants to hide some databases
-     *
-     * @todo temporaly use this docblock to test how to doc $GLOBALS
-     * @uses    PMA_List_Database::$items
-     * @uses    preg_match()
-     * @uses    $cfg['Server']['hide_db']
      */
     protected function _checkHideDatabase()
     {
@@ -97,25 +93,19 @@ require_once './libraries/List.class.php';
      * retrieves database list from server
      *
      * @todo    we could also search mysql tables if all fail?
-     * @uses    PMA_List_Database::$_show_databases_disabled for not retrying if SHOW DATABASES is disabled
-     * @uses    PMA_List_Database::$_db_link
-     * @uses    PMA_List_Database::$_db_link_control in case of SHOW DATABASES is disabled for userlink
-     * @uses    PMA_DBI_fetch_result()
-     * @uses    PMA_DBI_getError()
-     * @uses    $GLOBALS['error_showdatabases']
-     * @uses    $GLOBALS['errno']
-     * @param   string  $like_db_name   usally a db_name containing wildcards
+     * @param string  $like_db_name   usally a db_name containing wildcards
+     * @return array
      */
     protected function _retrieve($like_db_name = null)
     {
         if ($this->_show_databases_disabled) {
             return array();
         }
-        
+
         if (null !== $like_db_name) {
             $command = "SHOW DATABASES LIKE '" . $like_db_name . "'";
         } elseif (null === $this->_command) {
-            $command = str_replace('#user#', $GLOBALS['cfg']['Server']['user'], 
+            $command = str_replace('#user#', $GLOBALS['cfg']['Server']['user'],
                 $GLOBALS['cfg']['Server']['ShowDatabasesCommand']);
             $this->_command = $command;
         } else {
@@ -142,47 +132,34 @@ require_once './libraries/List.class.php';
             }
         }
 
+        if ($GLOBALS['cfg']['NaturalOrder']) {
+            natsort($database_list);
+        } else {
+            // need to sort anyway, otherwise information_schema
+            // goes at the top
+            sort($database_list);
+        }
+
         return $database_list;
     }
 
     /**
      * builds up the list
      *
-     * @uses    PMA_List_Database::$items to initialize it
-     * @uses    PMA_List_Database::_checkOnlyDatabase()
-     * @uses    PMA_List_Database::_retrieve()
-     * @uses    PMA_List_Database::_checkHideDatabase()
-     * @uses    array_values()
-     * @uses    natsort()
-     * @uses    $cfg['NaturalOrder']
      */
     public function build()
     {
         if (! $this->_checkOnlyDatabase()) {
             $items = $this->_retrieve();
-            if ($GLOBALS['cfg']['NaturalOrder']) {
-                natsort($items);
-            }
             $this->exchangeArray($items);
         }
-        
+
         $this->_checkHideDatabase();
     }
 
     /**
      * checks the only_db configuration
      *
-     * @uses    PMA_List_Database::$_show_databases_disabled
-     * @uses    PMA_List_Database::$items
-     * @uses    PMA_List_Database::_retrieve()
-     * @uses    PMA_unescape_mysql_wildcards()
-     * @uses    preg_match()
-     * @uses    array_diff()
-     * @uses    array_merge()
-     * @uses    is_array()
-     * @uses    strlen()
-     * @uses    is_string()
-     * @uses    $cfg['Server']['only_db']
      * @return  boolean false if there is no only_db, otherwise true
      */
     protected function _checkOnlyDatabase()
@@ -197,7 +174,7 @@ require_once './libraries/List.class.php';
         if (! is_array($GLOBALS['cfg']['Server']['only_db'])) {
             return false;
         }
-        
+
         $items = array();
 
         foreach ($GLOBALS['cfg']['Server']['only_db'] as $each_only_db) {
@@ -224,7 +201,7 @@ require_once './libraries/List.class.php';
 
             // @todo induce error, about not using wildcards with SHOW DATABASE disabled?
         }
-        
+
         $this->exchangeArray($items);
 
         return true;
@@ -233,9 +210,6 @@ require_once './libraries/List.class.php';
     /**
      * returns default item
      *
-     * @uses    PMA_List::getEmpty()
-     * @uses    $GLOBALS['db']
-     * @uses    strlen()
      * @return  string  default item
      */
     public function getDefault()
@@ -250,49 +224,52 @@ require_once './libraries/List.class.php';
     /**
      * returns array with dbs grouped with extended infos
      *
-     * @uses    $GLOBALS['PMA_List_Database']
-     * @uses    $GLOBALS['cfgRelation']['commwork']
-     * @uses    $cfg['ShowTooltip']
-     * @uses    $cfg['LeftFrameDBTree']
-     * @uses    $cfg['LeftFrameDBSeparator']
-     * @uses    $cfg['ShowTooltipAliasDB']
-     * @uses    PMA_getTableCount()
-     * @uses    PMA_getDbComment()
-     * @uses    is_array()
-     * @uses    implode()
-     * @uses    strstr()
-     * @uses    explode()
-     * @param   integer $offset
-     * @param   integer $count
+     * @param integer $offset
+     * @param integer $count
      * @return  array   db list
      */
     public function getGroupedDetails($offset, $count)
     {
         $dbgroups   = array();
-        $parts      = array();
 
         if ($GLOBALS['cfg']['ShowTooltip']
           && $GLOBALS['cfgRelation']['commwork']) {
             $db_tooltips = PMA_getDbComments();
         }
 
-        foreach ($this->getLimitedItems($offset, $count) as $key => $db) {
-            // garvin: Get comments from PMA comments table
+        if (!$GLOBALS['cfg']['LeftFrameDBTree']) {
+            $separators = array();
+        } elseif (is_array($GLOBALS['cfg']['LeftFrameDBSeparator'])) {
+            $separators = $GLOBALS['cfg']['LeftFrameDBSeparator'];
+        } elseif (!empty($GLOBALS['cfg']['LeftFrameDBSeparator'])) {
+            $separators = array($GLOBALS['cfg']['LeftFrameDBSeparator']);
+        } else {
+            $separators = array();
+        }
+
+        foreach ($this->getLimitedItems($offset, $count) as $db) {
+            // Get comments from PMA comments table
             $db_tooltip = '';
 
             if (isset($db_tooltips[$db])) {
                 $db_tooltip = $db_tooltips[$db];
             }
 
-            if ($GLOBALS['cfg']['LeftFrameDBTree']
-                && $GLOBALS['cfg']['LeftFrameDBSeparator']
-                && strstr($db, $GLOBALS['cfg']['LeftFrameDBSeparator']))
-            {
+            $pos = false;
+
+            foreach ($separators as $separator) {
                 // use strpos instead of strrpos; it seems more common to
                 // have the db name, the separator, then the rest which
                 // might contain a separator
                 // like dbname_the_rest
-                $pos            = strpos($db, $GLOBALS['cfg']['LeftFrameDBSeparator']);
+                $pos = strpos($db, $separator, 1);
+
+                if ($pos !== false) {
+                    break;
+                }
+            }
+
+            if ($pos !== false) {
                 $group          = substr($db, 0, $pos);
                 $disp_name_cut  = substr($db, $pos);
             } else {
@@ -313,7 +290,7 @@ require_once './libraries/List.class.php';
                 'disp_name'     => $disp_name,
                 'comment'       => $db_tooltip,
             );
-            
+
             if ($GLOBALS['cfg']['Server']['CountTables']) {
                 $dbgroups[$group][$db]['num_tables'] = PMA_getTableCount($db);
             }
@@ -324,9 +301,8 @@ require_once './libraries/List.class.php';
     /**
      * returns a part of the items
      *
-     * @uses    array_slice()
-     * @param   integer $offset
-     * @param   integer $count
+     * @param integer $offset
+     * @param integer $count
      * @return  array  some items
      */
     public function getLimitedItems($offset, $count)
@@ -348,7 +324,7 @@ require_once './libraries/List.class.php';
         $return = '<ul id="databaseList" xml:lang="en" dir="ltr">' . "\n";
         foreach ($this->getGroupedDetails($offset, $count) as $group => $dbs) {
             if (count($dbs) > 1) {
-                $return .= '<li>' . htmlspecialchars($group) . '<ul>' . "\n";
+                $return .= '<li class="group"><span>' . htmlspecialchars($group) . '</span><ul>' . "\n";
                 // whether display db_name cut by the group part
                 $cut = true;
             } else {
@@ -371,7 +347,7 @@ require_once './libraries/List.class.php';
                 } else {
                     $return .= htmlspecialchars($db['disp_name']);
                 }
-                
+
                 if (! empty($db['num_tables'])) {
                     $return .= ' (' . $db['num_tables'] . ')';
                 }
@@ -404,7 +380,7 @@ require_once './libraries/List.class.php';
         $return = '<select name="db" id="lightm_db" xml:lang="en" dir="ltr"'
             . ' onchange="if (this.value != \'\') window.parent.openDb(this.value);">' . "\n"
             . '<option value="" dir="' . $GLOBALS['text_dir'] . '">'
-            . '(' . $GLOBALS['strDatabases'] . ') ...</option>' . "\n";
+            . '(' . __('Databases') . ') ...</option>' . "\n";
         foreach ($this->getGroupedDetails($offset, $count) as $group => $dbs) {
             if (count($dbs) > 1) {
                 $return .= '<optgroup label="' . htmlspecialchars($group)
@@ -418,7 +394,7 @@ require_once './libraries/List.class.php';
             foreach ($dbs as $db) {
                 $return .= '<option value="' . htmlspecialchars($db['name']) . '"'
                     .' title="' . htmlspecialchars($db['comment']) . '"';
-                if ($db['name'] == $selected) {
+                if ($db['name'] == $selected || (PMA_DRIZZLE && strtolower($db['name']) == strtolower($selected))) {
                     $return .= ' selected="selected"';
                 }
                 $return .= '>' . htmlspecialchars($cut ? $db['disp_name_cut'] : $db['disp_name']);
@@ -444,12 +420,12 @@ require_once './libraries/List.class.php';
     protected function _checkAgainstPrivTables()
     {
         // 1. get allowed dbs from the "mysql.db" table
-        // lem9: User can be blank (anonymous user)
+        // User can be blank (anonymous user)
         $local_query = "
             SELECT DISTINCT `Db` FROM `mysql`.`db`
             WHERE `Select_priv` = 'Y'
             AND `User`
-            IN ('" . PMA_sqlAddslashes($GLOBALS['cfg']['Server']['user']) . "', '')";
+            IN ('" . PMA_sqlAddSlashes($GLOBALS['cfg']['Server']['user']) . "', '')";
         $tmp_mydbs = PMA_DBI_fetch_result($local_query, null, null,
             $GLOBALS['controllink']);
         if ($tmp_mydbs) {
@@ -464,7 +440,7 @@ require_once './libraries/List.class.php';
             // now populated with actual database names instead of
             // with regular expressions.
             $tmp_alldbs = PMA_DBI_query('SHOW DATABASES;', $GLOBALS['controllink']);
-            // loic1: all databases cases - part 2
+            // all databases cases - part 2
             if (isset($tmp_mydbs['%'])) {
                 while ($tmp_row = PMA_DBI_fetch_row($tmp_alldbs)) {
                     $dblist[] = $tmp_row[0];
@@ -475,16 +451,16 @@ require_once './libraries/List.class.php';
                     if (isset($tmp_mydbs[$tmp_db]) && $tmp_mydbs[$tmp_db] == 1) {
                         $dblist[]           = $tmp_db;
                         $tmp_mydbs[$tmp_db] = 0;
-                    } elseif (!isset($dblist[$tmp_db])) {
+                    } elseif (! isset($dblist[$tmp_db])) {
                         foreach ($tmp_mydbs as $tmp_matchpattern => $tmp_value) {
-                            // loic1: fixed bad regexp
+                            // fixed bad regexp
                             // TODO: db names may contain characters
                             //       that are regexp instructions
                             $re        = '(^|(\\\\\\\\)+|[^\])';
-                            $tmp_regex = preg_replace('/' . addcslashes($re,'/') . '%/', '\\1.*', preg_replace('/' . addcslashes($re,'/') . '_/', '\\1.{1}', $tmp_matchpattern));
+                            $tmp_regex = preg_replace('/' . addcslashes($re, '/') . '%/', '\\1.*', preg_replace('/' . addcslashes($re, '/') . '_/', '\\1.{1}', $tmp_matchpattern));
                             // Fixed db name matching
                             // 2000-08-28 -- Benjamin Gandon
-                            if (preg_match('/^' . addcslashes($tmp_regex,'/') . '$/', $tmp_db)) {
+                            if (preg_match('/^' . addcslashes($tmp_regex, '/') . '$/', $tmp_db)) {
                                 $dblist[] = $tmp_db;
                                 break;
                             }
@@ -497,7 +473,7 @@ require_once './libraries/List.class.php';
         } // end if
 
         // 2. get allowed dbs from the "mysql.tables_priv" table
-        $local_query = 'SELECT DISTINCT Db FROM mysql.tables_priv WHERE Table_priv LIKE \'%Select%\' AND User = \'' . PMA_sqlAddslashes($GLOBALS['cfg']['Server']['user']) . '\'';
+        $local_query = 'SELECT DISTINCT Db FROM mysql.tables_priv WHERE Table_priv LIKE \'%Select%\' AND User = \'' . PMA_sqlAddSlashes($GLOBALS['cfg']['Server']['user']) . '\'';
         $rs          = PMA_DBI_try_query($local_query, $GLOBALS['controllink']);
         if ($rs && @PMA_DBI_num_rows($rs)) {
             while ($row = PMA_DBI_fetch_assoc($rs)) {
