@@ -8,12 +8,18 @@
  *
  * Order of sections for common.inc.php:
  *
+ * the authentication libraries must be before the connection to db
+ *
+ * ... so the required order is:
+ *
  * LABEL_variables_init
  *  - initialize some variables always needed
  * LABEL_parsing_config_file
  *  - parsing of the configuration file
  * LABEL_loading_language_file
  *  - loading language file
+ * LABEL_setup_servers
+ *  - check and setup configured servers
  * LABEL_theme_setup
  *  - setting up themes
  *
@@ -22,30 +28,63 @@
  * - db connection
  * - authentication work
  *
- * @version $Id: common.inc.php 11175 2008-03-29 06:06:35Z lem9 $
+ * @package PhpMyAdmin
  */
 
 /**
- * For now, avoid warnings of E_STRICT mode
- * (this must be done before function definitions)
+ * block attempts to directly run this script 
  */
-if (defined('E_STRICT')) {
-    $old_error_reporting = error_reporting(0);
-    if ($old_error_reporting & E_STRICT) {
-        error_reporting($old_error_reporting ^ E_STRICT);
-    } else {
-        error_reporting($old_error_reporting);
-    }
-    unset($old_error_reporting);
+if (getcwd() == dirname(__FILE__)) {
+    die('Attack stopped');
 }
 
-// at this point PMA_PHP_INT_VERSION is not yet defined
-if (version_compare(phpversion(), '6', 'lt')) {
+/**
+ * Minimum PHP version; can't call PMA_fatalError() which uses a
+ * PHP 5 function, so cannot easily localize this message.
+ */
+if (version_compare(PHP_VERSION, '5.2.0', 'lt')) {
+    die('PHP 5.2+ is required');
+}
+
+/**
+  * Backward compatibility for PHP 5.2
+  */
+if (!defined('E_DEPRECATED')) {
+    define('E_DEPRECATED', 8192);
+}
+
+/**
+ * for verification in all procedural scripts under libraries
+ */
+define('PHPMYADMIN', true);
+
+/**
+ * the error handler
+ */
+require './libraries/Error_Handler.class.php';
+
+/**
+ * initialize the error handler
+ */
+$GLOBALS['error_handler'] = new PMA_Error_Handler();
+$cfg['Error_Handler']['display'] = true;
+
+/*
+ * This setting was removed in PHP 5.3. But at this point PMA_PHP_INT_VERSION
+ * is not yet defined so we use another way to find out the PHP version.
+ */
+if (version_compare(phpversion(), '5.3', 'lt')) {
     /**
      * Avoid object cloning errors
      */
     @ini_set('zend.ze1_compatibility_mode', false);
+}
 
+/**
+ * This setting was removed in PHP 5.4. But at this point PMA_PHP_INT_VERSION
+ * is not yet defined so we use another way to find out the PHP version.
+ */
+if (version_compare(phpversion(), '5.4', 'lt')) {
     /**
      * Avoid problems with magic_quotes_runtime
      */
@@ -55,69 +94,68 @@ if (version_compare(phpversion(), '6', 'lt')) {
 /**
  * core functions
  */
-require_once './libraries/core.lib.php';
+require './libraries/core.lib.php';
 
 /**
  * Input sanitizing
  */
-require_once './libraries/sanitizing.lib.php';
+require './libraries/sanitizing.lib.php';
 
 /**
  * the PMA_Theme class
  */
-require_once './libraries/Theme.class.php';
+require './libraries/Theme.class.php';
 
 /**
  * the PMA_Theme_Manager class
  */
-require_once './libraries/Theme_Manager.class.php';
+require './libraries/Theme_Manager.class.php';
 
 /**
  * the PMA_Config class
  */
-require_once './libraries/Config.class.php';
+require './libraries/Config.class.php';
+
+/**
+ * the relation lib, tracker needs it
+ */
+require './libraries/relation.lib.php';
+
+/**
+ * the PMA_Tracker class
+ */
+require './libraries/Tracker.class.php';
 
 /**
  * the PMA_Table class
  */
-require_once './libraries/Table.class.php';
+require './libraries/Table.class.php';
 
 if (!defined('PMA_MINIMUM_COMMON')) {
     /**
      * common functions
      */
-    require_once './libraries/common.lib.php';
+    include_once './libraries/common.lib.php';
 
     /**
      * Java script escaping.
      */
-    require_once './libraries/js_escape.lib.php';
+    include_once './libraries/js_escape.lib.php';
 
     /**
      * Include URL/hidden inputs generating.
      */
-    require_once './libraries/url_generating.lib.php';
+    include_once './libraries/url_generating.lib.php';
 }
 
 /******************************************************************************/
 /* start procedural code                       label_start_procedural         */
 
-/**
- * protect against older PHP versions' bug about GLOBALS overwrite
- * (no need to localize this message :))
- * but what if script.php?GLOBALS[admin]=1&GLOBALS[_REQUEST]=1 ???
- */
-if (isset($_REQUEST['GLOBALS']) || isset($_FILES['GLOBALS'])
-  || isset($_SERVER['GLOBALS']) || isset($_COOKIE['GLOBALS'])
-  || isset($_ENV['GLOBALS'])) {
-    die('GLOBALS overwrite attempt');
-}
-
 /**
  * protect against possible exploits - there is no need to have so much variables
  */
 if (count($_REQUEST) > 1000) {
-    die('possible exploit');
+    die(__('possible exploit'));
 }
 
 /**
@@ -126,9 +164,10 @@ if (count($_REQUEST) > 1000) {
  */
 foreach ($GLOBALS as $key => $dummy) {
     if (is_numeric($key)) {
-        die('numeric key detected');
+        die(__('numeric key detected'));
     }
 }
+unset($dummy);
 
 /**
  * PATH_INFO could be compromised if set, so remove it from PHP_SELF
@@ -147,7 +186,8 @@ $PMA_PHP_SELF = htmlspecialchars($PMA_PHP_SELF);
 
 /**
  * just to be sure there was no import (registering) before here
- * we empty the global space
+ * we empty the global space (but avoid unsetting $variables_list
+ * and $key in the foreach (), we still need them!)
  */
 $variables_whitelist = array (
     'GLOBALS',
@@ -159,7 +199,10 @@ $variables_whitelist = array (
     '_ENV',
     '_COOKIE',
     '_SESSION',
+    'error_handler',
     'PMA_PHP_SELF',
+    'variables_whitelist',
+    'key'
 );
 
 foreach (get_defined_vars() as $key => $value) {
@@ -188,7 +231,7 @@ unset($key, $value, $variables_whitelist);
  * ... main form elments ...
  * <input type="submit" name="main_action" value="submit form" />
  * </form>
- * </code
+ * </code>
  *
  * so we now check if a subform is submitted
  */
@@ -214,59 +257,126 @@ if (isset($_POST['usesubform'])) {
 } else {
     // Note: here we overwrite $_REQUEST so that it does not contain cookies,
     // because another application for the same domain could have set
-    // a cookie (with a compatible path) that overrides a variable 
+    // a cookie (with a compatible path) that overrides a variable
     // we expect from GET or POST.
     // We'll refer to cookies explicitly with the $_COOKIE syntax.
     $_REQUEST = array_merge($_GET, $_POST);
 }
 // end check if a subform is submitted
 
-// remove quotes added by php
-if (function_exists('get_magic_quotes_gpc') && get_magic_quotes_gpc()) {
-    PMA_arrayWalkRecursive($_GET, 'stripslashes', true);
-    PMA_arrayWalkRecursive($_POST, 'stripslashes', true);
-    PMA_arrayWalkRecursive($_COOKIE, 'stripslashes', true);
-    PMA_arrayWalkRecursive($_REQUEST, 'stripslashes', true);
-}
-
 /**
- * clean cookies on new install or upgrade
- * when changing something with increment the cookie version
+ * This setting was removed in PHP 5.4. But at this point PMA_PHP_INT_VERSION
+ * is not yet defined so we use another way to find out the PHP version.
  */
-$pma_cookie_version = 4;
-if (isset($_COOKIE)
- && (! isset($_COOKIE['pmaCookieVer'])
-  || $_COOKIE['pmaCookieVer'] < $pma_cookie_version)) {
-    // delete all cookies
-    foreach($_COOKIE as $cookie_name => $tmp) {
-        PMA_removeCookie($cookie_name);
+if (version_compare(phpversion(), '5.4', 'lt')) {
+    // remove quotes added by PHP
+    if (function_exists('get_magic_quotes_gpc') && get_magic_quotes_gpc()) {
+        PMA_arrayWalkRecursive($_GET, 'stripslashes', true);
+        PMA_arrayWalkRecursive($_POST, 'stripslashes', true);
+        PMA_arrayWalkRecursive($_COOKIE, 'stripslashes', true);
+        PMA_arrayWalkRecursive($_REQUEST, 'stripslashes', true);
     }
-    $_COOKIE = array();
-    PMA_setCookie('pmaCookieVer', $pma_cookie_version);
 }
 
 /**
  * include deprecated grab_globals only if required
  */
 if (empty($__redirect) && !defined('PMA_NO_VARIABLES_IMPORT')) {
-    require './libraries/grab_globals.lib.php';
+    include './libraries/grab_globals.lib.php';
 }
 
+/**
+ * check timezone setting
+ * this could produce an E_STRICT - but only once,
+ * if not done here it will produce E_STRICT on every date/time function
+ *
+ * @todo need to decide how we should handle this (without @)
+ */
+date_default_timezone_set(@date_default_timezone_get());
+
+/******************************************************************************/
+/* parsing configuration file                         LABEL_parsing_config_file      */
+
+/**
+ * We really need this one!
+ */
+if (! function_exists('preg_replace')) {
+    PMA_warnMissingExtension('pcre', true);
+}
+
+/**
+ * @global PMA_Config $GLOBALS['PMA_Config']
+ * force reading of config file, because we removed sensitive values
+ * in the previous iteration
+ */
+$GLOBALS['PMA_Config'] = new PMA_Config(CONFIG_FILE);
+
+if (!defined('PMA_MINIMUM_COMMON')) {
+    $GLOBALS['PMA_Config']->checkPmaAbsoluteUri();
+}
+
+/**
+ * BC - enable backward compatibility
+ * exports all configuration settings into $GLOBALS ($GLOBALS['cfg'])
+ */
+$GLOBALS['PMA_Config']->enableBc();
+
+/**
+ * clean cookies on upgrade
+ * when changing something related to PMA cookies, increment the cookie version
+ */
+$pma_cookie_version = 4;
+if (isset($_COOKIE)
+ && (isset($_COOKIE['pmaCookieVer'])
+  && $_COOKIE['pmaCookieVer'] < $pma_cookie_version)) {
+    // delete all cookies
+    foreach ($_COOKIE as $cookie_name => $tmp) {
+        $GLOBALS['PMA_Config']->removeCookie($cookie_name);
+    }
+    $_COOKIE = array();
+    $GLOBALS['PMA_Config']->setCookie('pmaCookieVer', $pma_cookie_version);
+}
+
+
+/**
+ * check HTTPS connection
+ */
+if ($GLOBALS['PMA_Config']->get('ForceSSL')
+    && ! $GLOBALS['PMA_Config']->get('is_https')
+) {
+    // grab current URL
+    $url = $GLOBALS['PMA_Config']->get('PmaAbsoluteUri');
+    // Parse current URL
+    $parsed = parse_url($url);
+    // In case parsing has failed do stupid string replacement
+    if ($parsed === false) {
+        // Replace http protocol
+        $url = preg_replace('@^http:@', 'https:', $url);
+    } else {
+        if($GLOBALS['PMA_Config']->get('SSLPort')) {
+            $port_number = $GLOBALS['PMA_Config']->get('SSLPort');
+        } else {
+            $port_number = 443;
+        }
+        $url = 'https://' . $parsed['host'] . ':' . $port_number . $parsed['path'];
+    }
+    // Actually redirect
+    PMA_sendHeaderLocation($url . PMA_generate_common_url($_GET, 'text'));
+    // delete the current session, otherwise we get problems (see bug #2397877)
+    $GLOBALS['PMA_Config']->removeCookie($GLOBALS['session_name']);
+    exit;
+}
+
+
 /**
  * include session handling after the globals, to prevent overwriting
  */
-require_once './libraries/session.inc.php';
+require './libraries/session.inc.php';
 
 /**
  * init some variables LABEL_variables_init
  */
 
-/**
- * holds errors
- * @global array $GLOBALS['PMA_errors']
- */
-$GLOBALS['PMA_errors'] = array();
-
 /**
  * holds parameters to be passed to next page
  * @global array $GLOBALS['url_params']
@@ -285,6 +395,7 @@ $goto_whitelist = array(
     'db_create.php',
     'db_datadict.php',
     'db_sql.php',
+    'db_events.php',
     'db_export.php',
     'db_importdocsql.php',
     'db_qbe.php',
@@ -293,8 +404,8 @@ $goto_whitelist = array(
     'db_operations.php',
     'db_printview.php',
     'db_search.php',
+    'db_routines.php',
     //'Documentation.html',
-    //'error.php',
     'export.php',
     'import.php',
     //'index.php',
@@ -313,7 +424,6 @@ $goto_whitelist = array(
     'server_export.php',
     'server_import.php',
     'server_privileges.php',
-    'server_processlist.php',
     'server_sql.php',
     'server_status.php',
     'server_variables.php',
@@ -334,10 +444,10 @@ $goto_whitelist = array(
     'tbl_replace.php',
     'tbl_row_action.php',
     'tbl_select.php',
+    'tbl_zoom_select.php',
     //'themes.php',
     'transformation_overview.php',
     'transformation_wrapper.php',
-    'translators.html',
     'user_password.php',
 );
 
@@ -380,25 +490,32 @@ if (PMA_checkPageValidity($_REQUEST['back'], $goto_whitelist)) {
  * f.e. PMA_Config: fontsize
  *
  * @todo variables should be handled by their respective owners (objects)
- * f.e. lang, server, convcharset, collation_connection in PMA_Config
+ * f.e. lang, server, collation_connection in PMA_Config
  */
 if (! PMA_isValid($_REQUEST['token']) || $_SESSION[' PMA_token '] != $_REQUEST['token']) {
     /**
      *  List of parameters which are allowed from unsafe source
      */
     $allow_list = array(
-        'db', 'table', 'lang', 'server', 'convcharset', 'collation_connection', 'target',
+        /* needed for direct access, see FAQ 1.34
+         * also, server needed for cookie login screen (multi-server)
+         */
+        'server', 'db', 'table', 'target', 'lang',
         /* Session ID */
         'phpMyAdmin',
         /* Cookie preferences */
-        'pma_lang', 'pma_charset', 'pma_collation_connection',
+        'pma_lang', 'pma_collation_connection',
         /* Possible login form */
         'pma_servername', 'pma_username', 'pma_password',
+        /* for playing blobstreamable media */
+        'media_type', 'custom_type', 'bs_reference',
+        /* for changing BLOB repository file MIME type */
+        'bs_db', 'bs_table', 'bs_ref', 'bs_new_mime_type',
     );
     /**
      * Require cleanup functions
      */
-    require_once './libraries/cleanup.lib.php';
+    include './libraries/cleanup.lib.php';
     /**
      * Do actual cleanup
      */
@@ -407,14 +524,6 @@ if (! PMA_isValid($_REQUEST['token']) || $_SESSION[' PMA_token '] != $_REQUEST['
 }
 
 
-/**
- * @global string $convcharset
- * @see select_lang.lib.php
- */
-if (isset($_REQUEST['convcharset'])) {
-    $convcharset = strip_tags($_REQUEST['convcharset']);
-}
-
 /**
  * current selected database
  * @global string $GLOBALS['db']
@@ -439,6 +548,18 @@ if (PMA_isValid($_REQUEST['table'])) {
     $GLOBALS['url_params']['table'] = $GLOBALS['table'];
 }
 
+/**
+ * Store currently selected recent table.
+ * Affect $GLOBALS['db'] and $GLOBALS['table']
+ */
+if (PMA_isValid($_REQUEST['selected_recent_table'])) {
+    $recent_table = json_decode($_REQUEST['selected_recent_table'], true);
+    $GLOBALS['db'] = $recent_table['db'];
+    $GLOBALS['url_params']['db'] = $GLOBALS['db'];
+    $GLOBALS['table'] = $recent_table['table'];
+    $GLOBALS['url_params']['table'] = $GLOBALS['table'];
+}
+
 /**
  * SQL query to be executed
  * @global string $GLOBALS['sql_query']
@@ -459,86 +580,73 @@ $_REQUEST['js_frame'] = PMA_ifSetOr($_REQUEST['js_frame'], '');
 //$_REQUEST['lang'];   // checked by LABEL_loading_language_file
 
 
-
-/******************************************************************************/
-/* parsing configuration file                         LABEL_parsing_config_file      */
+/**
+ * holds name of JavaScript files to be included in HTML header
+ * @global array $js_include
+ */
+$GLOBALS['js_include'] = array();
+$GLOBALS['js_include'][] = 'jquery/jquery-1.6.2+fix-9521.js';
+$GLOBALS['js_include'][] = 'jquery/jquery-ui-1.8.16.custom.js';
+$GLOBALS['js_include'][] = 'update-location.js';
 
 /**
- * We really need this one!
+ * holds an array of javascript code snippets to be included in the HTML header
+ * Can be used with PMA_AddJSCode() to pass on js variables to the browser.
+ * @global array $js_script
  */
-if (! function_exists('preg_replace')) {
-    PMA_fatalError('strCantLoad', 'pcre');
-}
+$GLOBALS['js_script'] = array();
 
 /**
- * @global PMA_Config $_SESSION['PMA_Config']
- * force reading of config file, because we removed sensitive values
- * in the previous iteration
+ * Add common jQuery functions script here if necessary.
  */
-$_SESSION['PMA_Config'] = new PMA_Config('./config.inc.php');
-
-if (!defined('PMA_MINIMUM_COMMON')) {
-    $_SESSION['PMA_Config']->checkPmaAbsoluteUri();
-}
 
 /**
- * BC - enable backward compatibility
- * exports all configuration settings into $GLOBALS ($GLOBALS['cfg'])
+ * JavaScript events that will be registered
+ * @global array $js_events
  */
-$_SESSION['PMA_Config']->enableBc();
-
+$GLOBALS['js_events'] = array();
 
 /**
- * check HTTPS connection
+ * footnotes to be displayed ot the page bottom
+ * @global array $footnotes
  */
-if ($_SESSION['PMA_Config']->get('ForceSSL')
-  && !$_SESSION['PMA_Config']->get('is_https')) {
-    PMA_sendHeaderLocation(
-        preg_replace('/^http/', 'https',
-            $_SESSION['PMA_Config']->get('PmaAbsoluteUri'))
-        . PMA_generate_common_url($_GET));
-    exit;
-}
-
+$GLOBALS['footnotes'] = array();
 
 /******************************************************************************/
 /* loading language file                       LABEL_loading_language_file    */
 
 /**
- * Added messages while developing:
+ * lang detection is done here
  */
-if (file_exists('./lang/added_messages.php')) {
-    include './lang/added_messages.php';
-}
-
-/**
- * Includes the language file if it hasn't been included yet
- */
-require './libraries/language.lib.php';
-
+require './libraries/select_lang.lib.php';
 
 /**
  * check for errors occurred while loading configuration
  * this check is done here after loading language files to present errors in locale
  */
-if ($_SESSION['PMA_Config']->error_config_file) {
-    $GLOBALS['PMA_errors'][] = $strConfigFileError
-        . '<br /><br />'
-        . ($_SESSION['PMA_Config']->getSource() == './config.inc.php' ?
-        '<a href="show_config_errors.php"'
-        .' target="_blank">' . $_SESSION['PMA_Config']->getSource() . '</a>'
-        :
-        '<a href="' . $_SESSION['PMA_Config']->getSource() . '"'
-        .' target="_blank">' . $_SESSION['PMA_Config']->getSource() . '</a>');
+$GLOBALS['PMA_Config']->checkPermissions();
+
+if ($GLOBALS['PMA_Config']->error_config_file) {
+    $error = '<h1>' . __('Failed to read configuration file') . '</h1>'
+        . _('This usually means there is a syntax error in it, please check any errors shown below.')
+        . '<br />'
+        . '<br />'
+        . '<iframe src="show_config_errors.php" />';
+    trigger_error($error, E_USER_ERROR);
 }
-if ($_SESSION['PMA_Config']->error_config_default_file) {
-    $GLOBALS['PMA_errors'][] = sprintf($strConfigDefaultFileError,
-        $_SESSION['PMA_Config']->default_source);
+if ($GLOBALS['PMA_Config']->error_config_default_file) {
+    $error = sprintf(__('Could not load default configuration from: %1$s'),
+        $GLOBALS['PMA_Config']->default_source);
+    trigger_error($error, E_USER_ERROR);
 }
-if ($_SESSION['PMA_Config']->error_pma_uri) {
-    $GLOBALS['PMA_errors'][] = sprintf($strPmaUriError);
+if ($GLOBALS['PMA_Config']->error_pma_uri) {
+    trigger_error(__('The <tt>$cfg[\'PmaAbsoluteUri\']</tt> directive MUST be set in your configuration file!'), E_USER_ERROR);
 }
 
+
+/******************************************************************************/
+/* setup servers                                       LABEL_setup_servers    */
+
 /**
  * current server
  * @global integer $GLOBALS['server']
@@ -551,7 +659,7 @@ $GLOBALS['server'] = 0;
  * @todo merge into PMA_Config
  */
 // Do we have some server?
-if (!isset($cfg['Servers']) || count($cfg['Servers']) == 0) {
+if (! isset($cfg['Servers']) || count($cfg['Servers']) == 0) {
     // No server => create one with defaults
     $cfg['Servers'] = array(1 => $default_server);
 } else {
@@ -562,14 +670,14 @@ if (!isset($cfg['Servers']) || count($cfg['Servers']) == 0) {
 
         // Detect wrong configuration
         if (!is_int($server_index) || $server_index < 1) {
-            $GLOBALS['PMA_errors'][] = sprintf($strInvalidServerIndex, $server_index);
+            trigger_error(sprintf(__('Invalid server index: %s'), $server_index), E_USER_ERROR);
         }
 
         $each_server = array_merge($default_server, $each_server);
 
         // Don't use servers with no hostname
         if ($each_server['connect_type'] == 'tcp' && empty($each_server['host'])) {
-            $GLOBALS['PMA_errors'][] = sprintf($strInvalidServerHostname, $server_index);
+            trigger_error(sprintf(__('Invalid hostname for server %1$s. Please review your configuration.'), $server_index), E_USER_ERROR);
         }
 
         // Final solution to bug #582890
@@ -578,7 +686,7 @@ if (!isset($cfg['Servers']) || count($cfg['Servers']) == 0) {
         // or the host field, then generate a name for the server
         // in the form of "Server 2", localized of course!
         if ($each_server['connect_type'] == 'socket' && empty($each_server['host']) && empty($each_server['verbose'])) {
-            $each_server['verbose'] = $GLOBALS['strServer'] . $server_index;
+            $each_server['verbose'] = __('Server') . $server_index;
         }
 
         $new_servers[$server_index] = $each_server;
@@ -607,7 +715,7 @@ if (! isset($_SESSION['PMA_Theme_Manager'])) {
 }
 
 // for the theme per server feature
-if (isset($_REQUEST['server']) && !isset($_REQUEST['set_theme'])) {
+if (isset($_REQUEST['server']) && ! isset($_REQUEST['set_theme'])) {
     $GLOBALS['server'] = $_REQUEST['server'];
     $tmp = $_SESSION['PMA_Theme_Manager']->getThemeCookie();
     if (empty($tmp)) {
@@ -665,16 +773,15 @@ if (! defined('PMA_MINIMUM_COMMON')) {
     /**
      * Character set conversion.
      */
-    require_once './libraries/charset_conversion.lib.php';
+    include_once './libraries/charset_conversion.lib.php';
 
     /**
      * String handling
      */
-    require_once './libraries/string.lib.php';
+    include_once './libraries/string.lib.php';
 
     /**
      * Lookup server by name
-     * by Arnold - Helder Hosting
      * (see FAQ 4.8)
      */
     if (! empty($_REQUEST['server']) && is_string($_REQUEST['server'])
@@ -714,48 +821,80 @@ if (! defined('PMA_MINIMUM_COMMON')) {
     }
     $GLOBALS['url_params']['server'] = $GLOBALS['server'];
 
+    /**
+     * Kanji encoding convert feature appended by Y.Kawada (2002/2/20)
+     */
+    if (function_exists('mb_convert_encoding')
+     && $lang == 'ja') {
+        include_once './libraries/kanji-encoding.lib.php';
+    } // end if
+
+    /**
+     * save some settings in cookies
+     * @todo should be done in PMA_Config
+     */
+    $GLOBALS['PMA_Config']->setCookie('pma_lang', $GLOBALS['lang']);
+    if (isset($GLOBALS['collation_connection'])) {
+        $GLOBALS['PMA_Config']->setCookie(
+            'pma_collation_connection',
+            $GLOBALS['collation_connection']);
+    }
+
+    $_SESSION['PMA_Theme_Manager']->setThemeCookie();
+
     if (! empty($cfg['Server'])) {
 
         /**
          * Loads the proper database interface for this server
          */
-        require_once './libraries/database_interface.lib.php';
+        include_once './libraries/database_interface.lib.php';
+
+        include_once './libraries/logging.lib.php';
+
+        // get LoginCookieValidity from preferences cache
+        // no generic solution for loading preferences from cache as some settings need to be kept
+        // for processing in PMA_Config::loadUserPreferences()
+        $cache_key = 'server_' . $GLOBALS['server'];
+        if (isset($_SESSION['cache'][$cache_key]['userprefs']['LoginCookieValidity'])) {
+            $value = $_SESSION['cache'][$cache_key]['userprefs']['LoginCookieValidity'];
+            $GLOBALS['PMA_Config']->set('LoginCookieValidity', $value);
+            $GLOBALS['cfg']['LoginCookieValidity'] = $value;
+            unset($value);
+        }
+        unset($cache_key);
 
         // Gets the authentication library that fits the $cfg['Server'] settings
         // and run authentication
 
-        // (for a quick check of path disclosure in auth/cookies:)
-        $coming_from_common = true;
-
         // to allow HTTP or http
         $cfg['Server']['auth_type'] = strtolower($cfg['Server']['auth_type']);
         if (! file_exists('./libraries/auth/' . $cfg['Server']['auth_type'] . '.auth.lib.php')) {
-            PMA_fatalError($strInvalidAuthMethod . ' ' . $cfg['Server']['auth_type']);
+            PMA_fatalError(__('Invalid authentication method set in configuration:') . ' ' . $cfg['Server']['auth_type']);
         }
         /**
          * the required auth type plugin
          */
-        require_once './libraries/auth/' . $cfg['Server']['auth_type'] . '.auth.lib.php';
-
+        include_once './libraries/auth/' . $cfg['Server']['auth_type'] . '.auth.lib.php';
         if (!PMA_auth_check()) {
+            /* Force generating of new session on login */
+            PMA_secureSession();
             PMA_auth();
         } else {
             PMA_auth_set_user();
         }
 
-        // Check IP-based Allow/Deny rules as soon as possible to reject the
+         // Check IP-based Allow/Deny rules as soon as possible to reject the
         // user
         // Based on mod_access in Apache:
         // http://cvs.apache.org/viewcvs.cgi/httpd-2.0/modules/aaa/mod_access.c?rev=1.37&content-type=text/vnd.viewcvs-markup
         // Look at: "static int check_dir_access(request_rec *r)"
-        // Robbat2 - May 10, 2002
         if (isset($cfg['Server']['AllowDeny'])
-          && isset($cfg['Server']['AllowDeny']['order'])) {
+                && isset($cfg['Server']['AllowDeny']['order'])) {
 
             /**
              * ip based access library
              */
-            require_once './libraries/ip_allow_deny.lib.php';
+            include_once './libraries/ip_allow_deny.lib.php';
 
             $allowDeny_forbidden         = false; // default
             if ($cfg['Server']['AllowDeny']['order'] == 'allow,deny') {
@@ -784,7 +923,8 @@ if (! defined('PMA_MINIMUM_COMMON')) {
 
             // Ejects the user if banished
             if ($allowDeny_forbidden) {
-               PMA_auth_fails();
+                PMA_log_user($cfg['Server']['user'], 'allow-denied');
+                PMA_auth_fails();
             }
             unset($allowDeny_forbidden); //Clean up after you!
         } // end if
@@ -792,11 +932,23 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         // is root allowed?
         if (!$cfg['Server']['AllowRoot'] && $cfg['Server']['user'] == 'root') {
             $allowDeny_forbidden = true;
+            PMA_log_user($cfg['Server']['user'], 'root-denied');
             PMA_auth_fails();
             unset($allowDeny_forbidden); //Clean up after you!
         }
 
-        $bkp_track_err = @ini_set('track_errors', 1);
+        // is a login without password allowed?
+        if (!$cfg['Server']['AllowNoPassword'] && $cfg['Server']['password'] == '') {
+            $login_without_password_is_forbidden = true;
+            PMA_log_user($cfg['Server']['user'], 'empty-denied');
+            PMA_auth_fails();
+            unset($login_without_password_is_forbidden); //Clean up after you!
+        }
+
+        // if using TCP socket is not needed
+        if (strtolower($cfg['Server']['connect_type']) == 'tcp') {
+            $cfg['Server']['socket'] = '';
+        }
 
         // Try to connect MySQL with the control user profile (will be used to
         // get the privileges list for the current user but the true user link
@@ -804,107 +956,135 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         // scripts)
         $controllink = false;
         if ($cfg['Server']['controluser'] != '') {
-            $controllink = PMA_DBI_connect($cfg['Server']['controluser'],
-                $cfg['Server']['controlpass'], true);
+            if (! empty($cfg['Server']['controlhost'])) {
+                $controllink = PMA_DBI_connect($cfg['Server']['controluser'],
+                    $cfg['Server']['controlpass'], true,
+                    array('host' => $cfg['Server']['controlhost'])
+                );
+            } else {
+                $controllink = PMA_DBI_connect($cfg['Server']['controluser'],
+                    $cfg['Server']['controlpass'], true);
+            }
         }
-        if (! $controllink) {
-            $controllink = PMA_DBI_connect($cfg['Server']['user'],
-                $cfg['Server']['password'], true);
-        } // end if ... else
-
-        // Pass #1 of DB-Config to read in master level DB-Config will go here
-        // Robbat2 - May 11, 2002
 
         // Connects to the server (validates user's login)
         $userlink = PMA_DBI_connect($cfg['Server']['user'],
             $cfg['Server']['password'], false);
 
-        // Pass #2 of DB-Config to read in user level DB-Config will go here
-        // Robbat2 - May 11, 2002
+        if (! $controllink) {
+            $controllink = $userlink;
+        }
 
-        @ini_set('track_errors', $bkp_track_err);
-        unset($bkp_track_err);
+        /* Log success */
+        PMA_log_user($cfg['Server']['user']);
 
         /**
-         * If we auto switched to utf-8 we need to reread messages here
+         * with phpMyAdmin 3 we support MySQL >=5
+         * but only production releases:
+         *  - > 5.0.15
          */
-        if (defined('PMA_LANG_RELOAD')) {
-            require './libraries/language.lib.php';
+        if (PMA_MYSQL_INT_VERSION < 50015) {
+            PMA_fatalError(__('You should upgrade to %s %s or later.'), array('MySQL', '5.0.15'));
+        }
+
+        if (PMA_DRIZZLE) {
+            // DisableIS must be set to false for Drizzle, it maps SHOW commands
+            // to INFORMATION_SCHEMA queries anyway so it's fast on large servers
+            $cfg['Server']['DisableIS'] = false;
+            // SHOW OPEN TABLES is not supported by Drizzle
+            $cfg['SkipLockedTables'] = false;
         }
 
         /**
          * SQL Parser code
          */
-        require_once './libraries/sqlparser.lib.php';
+        include_once './libraries/sqlparser.lib.php';
 
         /**
          * SQL Validator interface code
          */
-        require_once './libraries/sqlvalidator.lib.php';
+        include_once './libraries/sqlvalidator.lib.php';
 
         /**
          * the PMA_List_Database class
          */
-        require_once './libraries/List_Database.class.php';
-        $PMA_List_Database = new PMA_List_Database($userlink, $controllink);
+        include_once './libraries/PMA.php';
+        $pma = new PMA;
+        $pma->userlink = $userlink;
+        $pma->controllink = $controllink;
 
         /**
          * some resetting has to be done when switching servers
          */
-        if (isset($_SESSION['userconf']['previous_server']) && $_SESSION['userconf']['previous_server'] != $GLOBALS['server']) {
-            unset($_SESSION['userconf']['navi_limit_offset']);
+        if (isset($_SESSION['tmp_user_values']['previous_server']) && $_SESSION['tmp_user_values']['previous_server'] != $GLOBALS['server']) {
+            unset($_SESSION['tmp_user_values']['navi_limit_offset']);
         }
-        $_SESSION['userconf']['previous_server'] = $GLOBALS['server'];
+        $_SESSION['tmp_user_values']['previous_server'] = $GLOBALS['server'];
 
     } // end server connecting
 
-    /**
-     * Kanji encoding convert feature appended by Y.Kawada (2002/2/20)
-     */
-    if (@function_exists('mb_convert_encoding')
-        && strpos(' ' . $lang, 'ja-')
-        && file_exists('./libraries/kanji-encoding.lib.php')) {
-        require_once './libraries/kanji-encoding.lib.php';
-        /**
-         * enable multibyte string support
-         */
-        define('PMA_MULTIBYTE_ENCODING', 1);
-    } // end if
-
-    /**
-     * save some settings in cookies
-     * @todo should be done in PMA_Config
-     */
-    PMA_setCookie('pma_lang', $GLOBALS['lang']);
-    PMA_setCookie('pma_charset', $GLOBALS['convcharset']);
-    PMA_setCookie('pma_collation_connection', $GLOBALS['collation_connection']);
-
-    $_SESSION['PMA_Theme_Manager']->setThemeCookie();
-
     /**
      * check if profiling was requested and remember it
      * (note: when $cfg['ServerDefault'] = 0, constant is not defined)
      */
-
-    if (PMA_profilingSupported() && isset($_REQUEST['profiling'])) {
+    if (isset($_REQUEST['profiling']) && PMA_profilingSupported()) {
         $_SESSION['profiling'] = true;
     } elseif (isset($_REQUEST['profiling_form'])) {
         // the checkbox was unchecked
         unset($_SESSION['profiling']);
     }
 
+    // library file for blobstreaming
+    include_once './libraries/blobstreaming.lib.php';
+
+    // checks for blobstreaming plugins and databases that support
+    // blobstreaming (by having the necessary tables for blobstreaming)
+    checkBLOBStreamingPlugins();
+
 } // end if !defined('PMA_MINIMUM_COMMON')
 
+// load user preferences
+$GLOBALS['PMA_Config']->loadUserPreferences();
+
 // remove sensitive values from session
-$_SESSION['PMA_Config']->set('blowfish_secret', '');
-$_SESSION['PMA_Config']->set('Servers', '');
-$_SESSION['PMA_Config']->set('default_server', '');
+$GLOBALS['PMA_Config']->set('blowfish_secret', '');
+$GLOBALS['PMA_Config']->set('Servers', '');
+$GLOBALS['PMA_Config']->set('default_server', '');
+
+/* Tell tracker that it can actually work */
+PMA_Tracker::enable();
+
+/**
+ * @global boolean $GLOBALS['is_ajax_request']
+ * @todo should this be moved to the variables init section above?
+ *
+ * Check if the current request is an AJAX request, and set is_ajax_request
+ * accordingly.  Suppress headers, footers and unnecessary output if set to
+ * true
+ */
+if (isset($_REQUEST['ajax_request']) && $_REQUEST['ajax_request'] == true) {
+    $GLOBALS['is_ajax_request'] = true;
+} else {
+    $GLOBALS['is_ajax_request'] = false;
+}
+
+/**
+ * @global  boolean $GLOBALS['grid_edit']
+ *
+ * Set to true if this is a request made during an grid edit process.  This
+ * request is made to retrieve the non-truncated/transformed values.
+ */
+if (isset($_REQUEST['grid_edit']) && $_REQUEST['grid_edit'] == true) {
+    $GLOBALS['grid_edit'] = true;
+} else {
+    $GLOBALS['grid_edit'] = false;
+}
 
 if (!empty($__redirect) && in_array($__redirect, $goto_whitelist)) {
     /**
      * include subform target page
      */
-    require $__redirect;
+    include $__redirect;
     exit();
 }
 ?>
